# AutoChrome

> AutoChrome 是基于 [DrissionPage](https://drissionpage.cn/) 封装的浏览器自动化工具，支持自动下载
> Chrome、丰富的页面操作、元素操作、网络监听、文件下载、日志管理等功能，适用于数据采集、自动化测试等场景。

注意：AutoChrome 是一个自用模块，部分功能 `未进行充分测试`，请谨慎使用！

## ✨ 主要功能

- 🛠️ 支持自动安装 `Chromium`，解决了打包环境缺失的问题
- 🍪 cookies 的获取与设置
- 🔄 封装了常见的 `网页翻页` 功能
- 👀 封装了 `网络监听` 功能
- ⬇️ 将浏览器下载和 requests 下载进行了封装
- ⬆️ 封装 `文件上传` 功能
- 🧬 `AutoChrome` 继承于 `DrissionPage`，支持 `DrissionPage` 的源方法和参数
- 📚 `源码`包含详细的参数和功能说明，包含 `DrissionPage` 源文档链接
- 🐞 模块是个人使用的一个工具，当初写的比较急，代码较为粗糙🤐...

---

## 📒 说明文档 📒

- [https://blog.csdn.net/xiaoqiangclub/article/details/148529468](https://blog.csdn.net/xiaoqiangclub/article/details/148529468)

---

## 💬 联系与支持

* 👨‍💻 作者：Xiaoqiang
* 📢 微信公众号：**XiaoqiangClub**
* 📧 反馈与建议请通过邮件联系：**[xiaoqiangclub@hotmail.com](mailto:xiaoqiangclub@hotmail.com)**
* ☕ **请我喝咖啡支持项目发展：**

![请我喝咖啡](https://gitee.com/xiaoqiangclub/xiaoqiangapps/raw/master/images/xiaoqiangclub_ad.png)
